/* * This file is part of libcontactspicker *
 * Copyright © 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright controlled by
 * Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the prior written consent
 * of Nokia Corporation. This material also contains confidential information which may
 * not be disclosed to others without the prior written consent of Nokia. */

#ifndef CONTACTSPICKER_H
#define CONTACTSPICKER_H

#include <QObject>
#include <QList>
#include <QString>
#include <QStringList>
#include <QVariantList>
#include <QWidget>

#include <QContact>

#include "contactspickersortfilter.h"

QTM_USE_NAMESPACE

class ContactsPickerPrivate;

class ContactsPicker : public QObject
{
    Q_OBJECT
public:
    ContactsPicker();
    ~ContactsPicker();
    /*!
     * Opens \a ContactsPicker and return immediately.
     * \param definitionNames List of definitionNames that the picked contact should at least contain
     * the signaled QContact can contain additional details also.
     * \param singleSelection Whether the UI will offer only a single selection, or allow selection of multiple contacts
     * \param filtering Optional parameter for showing only specific contacts in contact picker list.
     * By default, the picker will not apply any filter and show all contacts.
     * \param sorting Sorting order of the contacts in contact picker list.
     * By default, the picker will sort contacts by their names.
     */
    Q_DECL_DEPRECATED void show(const QStringList &definitionNames = QStringList(),
              bool singleSelection = true,
              ContactsPickerFilter::Filter filtering = ContactsPickerFilter::None,
              ContactsPickerSort::SortOrder sorting = ContactsPickerSort::SortByName);

    void show(const QList<QContactId> &preSelectedIds,
              const QStringList &definitionNames = QStringList(),
              bool singleSelection = true,
              ContactsPickerFilter::Filter filtering = ContactsPickerFilter::None,
              ContactsPickerSort::SortOrder sorting = ContactsPickerSort::SortByName);
    /*!
     * Opens \a ContactsPicker and block the call until the picker has been closed.
     * \param definitionNames List of definitionNames that the picked contact should at least contain
     * the signaled QContact can contain additional details also.
     * \param singleSelection Whether the UI will offer only a single selection, or allow selection of multiple contacts.
     * \param filtering Optional parameter for showing only specific contacts in contact picker list.
     * By default, the picker will not apply any filter and show all contacts
     * \param sorting Sorting order of the contacts in contact picker list.
     * By default, the picker will sort contacts by their names.
     *
     * \deprecated Use ::show instead
     */
    void exec(const QStringList &definitionNames  = QStringList(),
              bool singleSelection = true,
              ContactsPickerFilter::Filter filtering = ContactsPickerFilter::None,
              ContactsPickerSort::SortOrder sorting = ContactsPickerSort::SortByName);
Q_SIGNALS:
    /*!
     * Emitted when contact picking has been finished.
     */
    void contactsPicked(const QList<QContact> &);
private Q_SLOTS:
    void onServiceUnavailable(const QString &);
    void onContactsPicked(const QVariantList &, const QString &);
    void resultsAvailable();
private:
    WId windowId();

    ContactsPickerPrivate * const d;

    void done(const QList<QContact> &contacts = QList<QContact>());
};

#endif
