/* * This file is part of libs/services*
 * Copyright © 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright controlled by
 * Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the prior written consent
 * of Nokia Corporation. This material also contains confidential information which may
 * not be disclosed to others without the prior written consent of Nokia. */

#ifndef CONTACTSPICKERSORTFILTER_H
#define CONTACTSPICKERSORTFILTER_H

#include <QObject>

/*!
 * \class ContactsPickerSort
 * \brief sorting enum for openContactsPicker method
 */

/*!
 * \enum ContactsPickerSort::SortOrder
 * Describes the sorting order of the contact list in a picker
 * \value SortByNone Don't sort the list
 * \value SortByName Sort by name
 * \value SortByPresence Sort by presence (e.g. online/busy/offline), then by name
 */

class ContactsPickerSort : public QObject
{
    // The class defining the enum has to inherit QObject as well as declare the enum using Q_ENUMS()
    Q_OBJECT
    Q_ENUMS(SortOrder)

public:
    enum SortOrder {
        SortByNone = -1,
        SortByName,
        SortByPresence
    };
};

/*!
 * \class ContactsPickerFilter
 * \brief filtering flags for openContactsPicker method
 */

/*!
 * \enum ContactsPickerFilter::Filter
 * Describes filters for contact picker. For instance, Call UI wants to see
 * all callable contacts, so the picker is filtered by CellularCall | VoIPCall
 * \value None No filter is applied, so the picker will show all contacts
 * \value Chat Filter the picker by Text-chat (IM) action, so only IM contacts will be shown
 * \value CellularCall Filter by Cellular call action
 * \value VoIPCall Filter by VoIP call action
 * \value SMS Filter by SMS action
 * \value Email Filter by Email action
 */

class ContactsPickerFilter : public QObject
{
    Q_OBJECT

public:
    enum FilterFlag {
        None          = 0,
        Chat          = 1 << 0,
        CellularCall  = 1 << 1,
        VoIPCall      = 1 << 2,
        SMS           = 1 << 3,
        Email         = 1 << 4,
        Editable      = 1 << 5,
        Account       = 1 << 6,
        Removable     = 1 << 7
    };
    Q_DECLARE_FLAGS(Filter, FilterFlag);
};

Q_DECLARE_OPERATORS_FOR_FLAGS(ContactsPickerFilter::Filter);

#endif // CONTACTSPICKERSORTFILTER_H
